/*
 *  Interactive disassembler (IDA).
 *  TheHyper VM Processor Module.
 *
 *  (c) 2006 Rolf Rolles
 */

#ifndef __INSTRS_HPP
#define __INSTRS_HPP

#include "../idaidp.hpp"

extern instruc_t Instructions[];

enum nameNum 
{
  TH_null = 0,    // Unknown Operation
  TH_mov,         // Move                
  TH_add,         // Add                 
  TH_sub,         // Subtract            
  TH_xor,         // Exclusive Bitwise OR
  TH_and,         // Bitwise And         
  TH_or,          // Bitwise OR          
  TH_imul,        // Integer Multiply    
  TH_idiv,        // Integer Divide      
  TH_imod,        // Integer Modulus     
  TH_ror,         // Bitwise Rotate Right
  TH_rol,         // Bitwise Rotate Left 
  TH_shr,         // Bitwise Shift Right 
  TH_shl,         // Bitwise Shift Left  
  TH_cmp,         // Comparison Operator 
  TH_push,        // Push To Stack       
  TH_pop,         // Pop From Stack      
  TH_inc,         // Increment Operator  
  TH_dec,         // Decrement Operator  
  TH_not,         // Bitwise Not Operator
  TH_jmp,         // Unconditional Branch                         
  TH_jz,          // Conditional (Zero         ) Branch Negative  
  TH_jnz,         // Conditional (Zero         ) Branch Positive  
  TH_jl,          // Conditional (Lesser       ) Branch
  TH_jle,         // Conditional (Lesser-Equal ) Branch
  TH_jg,          // Conditional (Greater      ) Branch
  TH_jge,         // Conditional (Greater-Equal) Branch
  TH_vmcall,      // Do call inside of VM                         
  TH_x86call,     // Do call inside of host process' address space
  TH_valloc,      // Alloc virtual memory via VirtualAlloc
  TH_vfree,       // Free  virtual memory via VirtualFree 
  TH_halloc,      // Alloc heap memory via HeapAlloc      
  TH_hfree,       // Free  heap memory via HeapFree       
  TH_geteip,      // Get current EIP              
  TH_getesp,      // Get current ESP              
  TH_getefl,      // Get EFLAGS                   
  TH_getmem,      // Get memory block by key      
  TH_retd,        // Retn VALUE                   
  TH_stop,        // Stop execution, return to x86
  TH_end          // No more instructions
};

#endif
